@@ -7,6 +7,7 @@ import pandas as pd
 import numpy as np
 
 from rich import print
+from tqdm import tqdm
 
 from iauditor_exporter.modules import csvExporter
 
@@ -76,6 +77,7 @@ def sync_exports(logger, settings, sc_client):
         get_started = sql_setup(logger, settings, "actions")
         export_actions(logger, settings, sc_client, get_started)
     if "actions" in settings[EXPORT_FORMATS]:
+        get_started = None
         get_started = None
         export_actions(logger, settings, sc_client, get_started)
     if not bool(
@@ -120,7 +122,21 @@ def sync_exports(logger, settings, sc_client):
             completed=completed_setting,
             archived=archived_setting,
         )
+
     if list_of_audits is not None:
+        if len(list_of_audits["audits"]) > 1000:
+            dupe_removal = []
+            new_audits = []
+            show_dupes = []
+            for audit in list_of_audits["audits"]:
+                if audit["audit_id"] not in dupe_removal:
+                    dupe_removal.append(audit["audit_id"])
+                    new_audits.append(audit)
+                else:
+                    show_dupes.append(audit)
+            list_of_audits["audits"] = new_audits
+
+        # list_of_audits['audits'] = list({v['audit_id']: v for v in list_of_audits['audits']}.values())
         logger.info(str(list_of_audits["total"]) + " audits discovered")
         export_count = 1
         export_total = list_of_audits["total"]
@@ -132,7 +148,7 @@ def sync_exports(logger, settings, sc_client):
         # back to square one. From testing, 500 is a good number to use here and I do not recommend
         # going higher.
 
-        per_chunk = 500
+        per_chunk = settings['chunks']
 
         if "sql" in settings[EXPORT_FORMATS]:
             get_started = sql_setup(logger, settings, "audit")
@@ -149,10 +165,18 @@ def sync_exports(logger, settings, sc_client):
             export_count,
             export_total,
             get_started,
+            per_chunk,
         )
 
         if "sql" in settings[EXPORT_FORMATS]:
             end_session(get_started[1])
+    else:
+        logger.error(
+            "There was a problem obtaining a list of inspections from the API. If the error above includes "
+            '"unauthorized", you will need to generate a new API token - just re-run the script with the --setup '
+            "parameter. If there is mention of a bad request, "
+            "double check the formatting of your last successful file and config file. "
+        )
 
 
 def loop_through_chunks(
@@ -163,24 +187,49 @@ def loop_through_chunks(
     export_count,
     export_total,
     get_started,
+    per_chunk,
 ):
+
     for chunk in chunks_to_process:
+        if per_chunk > export_total:
+            logger.info(f"Downloading {str(export_total)} total inspections...")
+        else:
+            logger.info(
+                f"Downloading {str(per_chunk)} of {str(export_total)} total inspections...)"
+            )
         audits_to_process = sc_client.raise_pool(chunk)
         all_audits = []
-        for audit in audits_to_process:
-            logger.info(
-                "Processing chunked audit ("
-                + str(export_count)
-                + "/"
-                + str(export_total)
-                + ")"
-            )
-            process_audit(
-                logger, settings, sc_client, audit, get_started, all_audits=all_audits
-            )
-            export_count += 1
+        audit_pbar = tqdm(
+            audits_to_process, total=export_total, initial=export_count - 1
+        )
+        debug_code = ""
+        modified_at = ""
+        for audit in audit_pbar:
+            if audit:
+                audit_pbar.set_description(f"Processing {audit['audit_id']}")
+                logger.debug(
+                    "Processing "
+                    + str(audit["audit_id"])
+                    + " - "
+                    + str(export_count)
+                    + "/"
+                    + str(export_total)
+                    + ")"
+                )
+                debug_code, modified_at = process_audit(
+                    logger,
+                    settings,
+                    sc_client,
+                    audit,
+                    get_started,
+                    all_audits=all_audits,
+                )
+                export_count += 1
         if "sql" in settings[EXPORT_FORMATS]:
             bulk_import_sql(logger, all_audits, get_started)
+        if debug_code and modified_at:
+            logger.debug(debug_code)
+            update_sync_marker_file(modified_at, settings[CONFIG_NAME])
 
 
 def process_audit(logger, settings, sc_client, audit, get_started, all_audits=[]):
@@ -206,18 +255,18 @@ def process_audit(logger, settings, sc_client, audit, get_started, all_audits=[]
     export_filename = (
         parse_export_filename(audit_json, settings[FILENAME_ITEM_ID]) or audit_id
     )
-    if "sql" in settings[EXPORT_FORMATS]:
-        if get_started[0] == "complete":
-            db_formatter(settings, audit, all_audits=all_audits)
-        elif get_started[0] != "complete":
-            logger.error(
-                "Something went wrong connecting to the database, please check your settings."
-            )
-            sys.exit(1)
-    elif "csv" in settings[EXPORT_FORMATS]:
-        export_audit_csv(settings, audit_json)
     for export_format in settings[EXPORT_FORMATS]:
-        if export_format in ["pdf", "docx"]:
+        if export_format == "sql":
+            if get_started[0] == "complete":
+                db_formatter(settings, audit, all_audits=all_audits)
+            elif get_started[0] != "complete":
+                logger.error(
+                    "Something went wrong connecting to the database, please check your settings."
+                )
+                sys.exit(1)
+        elif export_format == "csv":
+            export_audit_csv(settings, audit_json)
+        elif export_format in ["pdf", "docx"]:
             export_audit_pdf_word(
                 logger,
                 sc_client,
@@ -237,8 +286,12 @@ def process_audit(logger, settings, sc_client, audit, get_started, all_audits=[]
             export_audit_web_report_link(
                 logger, settings, sc_client, audit_json, audit_id, template_id
             )
-    logger.debug("setting last modified to " + audit["modified_at"])
-    update_sync_marker_file(audit["modified_at"], settings[CONFIG_NAME])
+    debug_code = "setting last modified to " + audit["modified_at"]
+    modified_at = audit["modified_at"]
+
+    return debug_code, modified_at
+    # logger.debug("setting last modified to " + audit["modified_at"])
+    # update_sync_marker_file(audit["modified_at"], settings[CONFIG_NAME])
 
 
 def db_formatter(settings, audit_json, all_audits=[]):
@@ -299,8 +352,9 @@ def db_formatter(settings, audit_json, all_audits=[]):
     df.replace(r"^\s*$", empty_value, regex=True, inplace=True)
     df["SortingIndex"] = range(1, len(df) + 1)
     df_dict = df.to_dict(orient="records")
-    for row in df_dict:
-        all_audits.append(row)
+    # for row in df_dict:
+    #     all_audits.append(row)
+    all_audits.append(df_dict)
 
 
 def loop(logger, sc_client, settings):
@@ -330,9 +384,10 @@ def main():
             preferences_to_list,
             loop_enabled,
             docker_enabled,
+            chunks,
         ) = parse_command_line_arguments(logger)
         sc_client, settings = configure(
-            logger, path_to_config_file, export_formats, docker_enabled
+            logger, path_to_config_file, export_formats, docker_enabled, chunks
         )
         if preferences_to_list is not None:
             show_preferences_and_exit(preferences_to_list, sc_client)
