@@ -118,6 +118,15 @@ smartfield_conditional_id_to_statement_map = {
     # conditional statements for textsingle field
     "6ff300f0-e501-11e1-aff1-0800200c9a66": "if text is",
     "6ff300f1-e501-11e1-aff1-0800200c9a66": "if text is not",
+    # conditional statements for number (textsingle) field
+    "a73aae9f-6ff2-4aac-a79d-beaf444170f0": "if the number is less than",
+    "f7029a02-befc-4b86-8eb5-aae824299dc6": "if the number is less than or equal to",
+    "32ff3989-8d98-4154-af7f-fd7b0b955a18": "if the number is equal to",
+    "f254d72f-2606-41dd-b3a5-61bddd22bfc2": "if the number is not equal to",
+    "f8b5db76-1941-444f-b14e-6f22109bb234": "if the number is greater than or equal to",
+    "2b4d02ea-087d-4853-a52f-84319df9c781": "if the number is greater than",
+    "1eaa9ca9-21be-437e-ab69-ac7cc203939b": "if the number is between",
+    "875d3438-353f-4ff9-8777-c1cc9dce6728": "if the number is not between",
     # conditional statements for signature field
     "831f8ff0-e500-11e1-aff1-0800200c9a66": "if signature exists",
     "831f8ff1-e500-11e1-aff1-0800200c9a66": "if the signature does not exist",
@@ -221,7 +230,7 @@ class CsvExporter:
         Recursively traverses the item Map, following parent IDs until it gets to a Section or Category.
         When a Section or Category is found, the item Category is set to the label of that Section or Category.
         :param item_id: item ID to find Category for
-        :return:        Category or Section label 
+        :return:        Category or Section label
         """
         if not item_id:
             return EMPTY_RESPONSE
@@ -490,6 +499,17 @@ class CsvExporter:
             )
         return response
 
+    @staticmethod
+    def get_item_comment(item):
+        """
+        :param item:    single item in JSON format
+        :return:        note/comment of item
+        """
+        if item.get(TYPE) in ["question", "list"]:
+            return get_json_property(item, RESPONSES, "text")
+        else:
+            return get_json_property(item, RESPONSES, "note")
+
     @staticmethod
     def get_item_response_id(item):
         """
@@ -542,10 +562,10 @@ class CsvExporter:
         :param item:    single item in JSON format
         :return:        score percentage property or empty string if property does not exist
         """
-        if isinstance(get_json_property(item, "scoring", SCORE_PERCENTAGE), int):
+        if isinstance(get_json_property(item, "scoring", SCORE_PERCENTAGE), float):
             return get_json_property(item, "scoring", SCORE_PERCENTAGE)
         elif isinstance(
-            get_json_property(item, "scoring", COMBINED_SCORE_PERCENTAGE), int
+            get_json_property(item, "scoring", COMBINED_SCORE_PERCENTAGE), float
         ):
             return get_json_property(item, "scoring", COMBINED_SCORE_PERCENTAGE)
         else:
@@ -602,29 +622,38 @@ class CsvExporter:
         :return:        item media href links
         """
         item_type = get_json_property(item, TYPE)
+        media_list = []
+
         if (
             item_type == INFORMATION
             and get_json_property(item, "options", TYPE) == MEDIA
         ):
-            media_href = "{}.{}".format(
-                get_json_property(item, "options", MEDIA, MEDIAID),
-                get_json_property(item, "options", MEDIA, EXT),
-            )
+            media_list = [
+                (
+                    "{}.{}".format(
+                        get_json_property(item, "options", MEDIA, MEDIAID),
+                        get_json_property(item, "options", MEDIA, EXT),
+                    )
+                )
+            ]
         elif item_type in ["drawing", SIGNATURE]:
-            media_href = "{}.{}".format(
-                get_json_property(item, RESPONSES, "image", MEDIAID),
-                get_json_property(item, RESPONSES, "image", EXT),
-            )
-        else:
-            media_list = []
-            for image in get_json_property(item, MEDIA):
-                if EXT in image.keys():
-                    if image[EXT] is not None:
-                        media_list.append(image[MEDIAID] + "." + image[EXT])
-                else:
-                    media_list.append(image[MEDIAID] + "." + "jpg")
-            media_href = "\n".join(media_list)
-            # media_href = '\n'.join(image[MEDIAID]+'.'+image[EXT] for image in get_json_property(item, MEDIA))
+            media_list = [
+                (
+                    "{}.{}".format(
+                        get_json_property(item, RESPONSES, "image", MEDIAID),
+                        get_json_property(item, RESPONSES, "image", EXT),
+                    )
+                )
+            ]
+
+        for image in get_json_property(item, MEDIA):
+            if EXT in image.keys():
+                if image[EXT] is not None:
+                    media_list.append(image[MEDIAID] + "." + image[EXT])
+            else:
+                media_list.append(image[MEDIAID] + "." + "jpg")
+        media_href = "\n".join(media_list)
+        # media_href = '\n'.join(image[MEDIAID]+'.'+image[EXT] for image in get_json_property(item, MEDIA))
         if media_href == ".":
             media_href = None
         return media_href
@@ -658,9 +687,7 @@ class CsvExporter:
             self.get_item_type(item),
             self.get_item_label(item),
             self.get_item_response(item),
-            get_json_property(item, RESPONSES, "text")
-            if item.get(TYPE) not in ["text", "textsingle"]
-            else EMPTY_RESPONSE,
+            self.get_item_comment(item),
             self.get_item_media(item),
             latitude,
             longitude,
